==> tecfy_corev2_package-1.1.30.tar.gz: lib/models/entity/property_bool.model.dart <==
part of tecfy_corev2_client_package;

class PropertyBoolean extends Property {
  late bool defaultValue;

  PropertyBoolean({
    required String dbName,
    required String nameAr,
    required String nameEn,
    bool isRequired = false,
    bool readOnly = false,
  }) : super(
            dbName: dbName,
            nameAr: nameAr,
            nameEn: nameEn,
            readOnly: readOnly,
            propertyType: PropertyTypes.Boolean,
            valueType: ValueTypes.Boolean,
            isRequired: isRequired);

  PropertyBoolean.fromMap(Map<String, dynamic> row) : super.fromMap(row) {
    //defaultValue = row['defaultValue'];
  }
  @override
  OperationResult isValid(data) {
    if (!super.isValid(data).success) return super.isValid(data);

    return OperationResult(success: true);
  }

  /// get the value and bind tp display widget
  Widget getDisplayWidget(Map<String, dynamic> data, {TextStyle? textStyle}) {
    return Transform.scale(
        scale: 0.8,
        child: SizedBox(
            height: 15.0,
            width: 15.0,
            child: (data[dbName] ?? false)
                ? Checkbox(value: true, onChanged: null)
                : Checkbox(value: false, onChanged: null)));
  }

  /// get the value in text
  String getDisplayText(Map<String, dynamic> data) {
    return (data[dbName] ?? false).toString();
  }

  Future<bool> getDefaultValue(Map<String, dynamic> data) async {
    if (data[dbName] != null) return false;
    if (defaultString?.isNotEmpty ?? false) {
      data[dbName] = (defaultString?.toLowerCase() == "true");
      return true;
    } else if (isRequired) {
      data[dbName] = false;
      return true;
    }
    return false;
  }
}

==> tecfy_corev2_package-1.1.109.tar.gz: lib/models/entity/property_bool.model.dart <==
part of tecfy_corev2_client_package;

class PropertyBoolean extends Property {
  late bool defaultValue;

  PropertyBoolean({
    required String dbName,
    required String nameAr,
    required String nameEn,
    bool isRequired = false,
    bool readOnly = false,
  }) : super(
            dbName: dbName,
            nameAr: nameAr,
            nameEn: nameEn,
            readOnly: readOnly,
            propertyType: PropertyTypes.Boolean,
            valueType: ValueTypes.Boolean,
            isRequired: isRequired);

  PropertyBoolean.fromMap(Map<String, dynamic> row) : super.fromMap(row) {
    //defaultValue = row['defaultValue'];
  }
  @override
  OperationResult isValid(data) {
    if (!super.isValid(data).success) return super.isValid(data);

    return OperationResult(success: true);
  }

  /// get the value and bind tp display widget
  Widget getDisplayWidget(Map<String, dynamic> data, {TextStyle? textStyle}) {
    return Transform.scale(
        scale: 0.8,
        child: SizedBox(
            height: 15.0,
            width: 15.0,
            child: (MapService.getValue(data, dbName) ?? false)
                ? Checkbox(value: true, onChanged: null)
                : Checkbox(value: false, onChanged: null)));
  }

  /// get the value in text
  String getDisplayText(Map<String, dynamic> data) {
    // return (data[dbName] ?? false).toString();
    return (MapService.getValue(data, dbName) ?? false).toString();
  }

  Future<bool> getDefaultValue(Map<String, dynamic> data) async {
    if (MapService.getValue(data, dbName) != null) return false;
    if (defaultString?.isNotEmpty ?? false) {
      // data[dbName] = (defaultString?.toLowerCase() == "true");
      MapService.updateValue(
          data, dbName, (defaultString?.toLowerCase() == "true"));
      return true;
    } else if (isRequired) {
      // data[dbName] = false;
      MapService.updateValue(
          data, dbName, (defaultString?.toLowerCase() == "true"));
      return true;
    }
    return false;
  }
}
